@@ -35,7 +35,7 @@ class ftpUtil:
             transport = paramiko.Transport((self.__hostname, self.__host_port))
             transport.connect(username=self.__username_stud, password=self.__password_stud)
             sftp = paramiko.SFTPClient.from_transport(transport)
-            pid="P" + prj_id.zfill(6)
+            pid="p" + prj_id.zfill(6)
             remotepath = self.__remotedir_stud + pid
             try:
                 sftp.chdir(remotepath)
@@ -58,7 +58,7 @@ class ftpUtil:
             # item['filename'] = local_path
             # item['url'] = self.__url_head+remote_file
             # item['stud'] = stud
-            self.__mutil.sftp_file_ins(local_path, self.__url_head +prj +'/'+ remote_file, stud,fdesc,fsize,duration,ftype,pid)
+            self.__mutil.sftp_file_ins(local_path, self.__url_head +pid +'/'+ remote_file, stud,fdesc,fsize,duration,ftype,pid)
         except Exception as ex:
             print("日志记录出现如下异常%s" % ex)
 
