@@ -114,7 +114,7 @@ class mysqlUtil:
             'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where pid="{}" order by uptime desc limit 100'.format(
                 pid)
         connection = self.engine.connect()
-        df = pd.read_sql(sql,  con=connection)
+        df = pd.read_sql(sql=sql,con=connection)
         results = json.loads(df.to_json(orient='records'))
         if results and len(results) == 1:
             return results[0]
